==> hrflow_connectors-4.26.1-py3-none-any.whl: hrflow_connectors/v2/connectors/recruitee/README.md <==
# 📖 Summary
- [📖 Summary](#📖-summary)
- [💼 About Recruitee](#💼-about-recruitee)
  - [😍 Why is it a big deal for Recruitee customers & partners?](#😍-why-is-it-a-big-deal-for-recruitee-customers--partners)
- [🔧 How does it work?](#🔧-how-does-it-work)
  - [📊 Data integration capabilities:](#📊-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#🧠-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#🔌-connector-actions)
- [💍 Quick Start Examples](#💍-quick-start-examples)
- [🔗 Useful Links](#🔗-useful-links)
- [👏 Special Thanks](#👏-special-thanks)


# 💼 About Recruitee

> Recruitee is an innovative and intuitive recruitment software that empowers businesses to streamline hiring processes and attract top talent. Recruitee provides a comprehensive solution that ensures a seamless and efficient recruitment experience.


## 😍 Why is it a big deal for Recruitee customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Recruitee customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Recruitee customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Recruitee to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Recruitee.
- ⬅️ Send Jobs data from Recruitee to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Recruitee.


## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Recruitee**)


# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Create profiles in hrflow**](docs/create_profiles_in_hrflow.md) | Send **created** 'profile(s)' _from_  _to_ HrFlow |
| [**Update profiles in hrflow**](docs/update_profiles_in_hrflow.md) | Send **updated** 'profile(s)' _from_  _to_ HrFlow |
| [**Archive profiles in hrflow**](docs/archive_profiles_in_hrflow.md) | Send **archived** 'profile(s)' _from_  _to_ HrFlow |
| [**Create profiles in **](docs/create_profiles_in_.md) | Send **created** 'profile(s)' _from_ HrFlow _to_  |
| [**Update profiles in **](docs/update_profiles_in_.md) | Send **updated** 'profile(s)' _from_ HrFlow _to_  |
| [**Archive profiles in **](docs/archive_profiles_in_.md) | Send **archived** 'profile(s)' _from_ HrFlow _to_  |
| [**Create jobs in hrflow**](docs/create_jobs_in_hrflow.md) | Send **created** 'job(s)' _from_  _to_ HrFlow |
| [**Update jobs in hrflow**](docs/update_jobs_in_hrflow.md) | Send **updated** 'job(s)' _from_  _to_ HrFlow |
| [**Archive jobs in hrflow**](docs/archive_jobs_in_hrflow.md) | Send **archived** 'job(s)' _from_  _to_ HrFlow |


</p>

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/ff726feb-d580-40f8-82b2-6c1132cebd8e width=90% height=100% >
</p>

# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.
To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :


<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/44360e84-ec0c-49a1-81dd-799840613c6a width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.

# 🔗 Useful Links

- 📄Visit [Recruitee](https://recruitee.com/) to learn more.
- ⚙️ API documentation : [Recruitee API](https://api.recruitee.com/docs/index.html)
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/recruitee) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai :  [Nedhir Ebnou](https://github.com/itsnedhir) - Software Engineer
- 🤝 Tellent : **Nuno Sequeira &  Diana De Freitas - Integrations Partners** for their help and collaboration in building this integration

==> hrflow_connectors-4.27.2-py3-none-any.whl: hrflow_connectors/v2/connectors/recruitee/README.md <==
# 📖 Summary
- [📖 Summary](#📖-summary)
- [💼 About Recruitee](#💼-about-recruitee)
  - [😍 Why is it a big deal for Recruitee customers & partners?](#😍-why-is-it-a-big-deal-for-recruitee-customers--partners)
- [🔧 How does it work?](#🔧-how-does-it-work)
  - [📊 Data integration capabilities:](#📊-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#🧠-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#🔌-connector-actions)
- [💍 Quick Start Examples](#💍-quick-start-examples)
- [🔗 Useful Links](#🔗-useful-links)
- [👏 Special Thanks](#👏-special-thanks)


# 💼 About Recruitee

> Recruitee is an innovative and intuitive recruitment software that empowers businesses to streamline hiring processes and attract top talent. Recruitee provides a comprehensive solution that ensures a seamless and efficient recruitment experience.


## 😍 Why is it a big deal for Recruitee customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Recruitee customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Recruitee customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Recruitee to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Recruitee.
- ⬅️ Send Jobs data from Recruitee to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Recruitee.

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/ff726feb-d580-40f8-82b2-6c1132cebd8e width=90% height=100% >
</p>

## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Recruitee**)


# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Create profiles in hrflow**](docs/create_profiles_in_hrflow.md) | Send **created** 'profile(s)' _from_  _to_ HrFlow |
| [**Update profiles in hrflow**](docs/update_profiles_in_hrflow.md) | Send **updated** 'profile(s)' _from_  _to_ HrFlow |
| [**Archive profiles in hrflow**](docs/archive_profiles_in_hrflow.md) | Send **archived** 'profile(s)' _from_  _to_ HrFlow |
| [**Create profiles in **](docs/create_profiles_in_.md) | Send **created** 'profile(s)' _from_ HrFlow _to_  |
| [**Update profiles in **](docs/update_profiles_in_.md) | Send **updated** 'profile(s)' _from_ HrFlow _to_  |
| [**Archive profiles in **](docs/archive_profiles_in_.md) | Send **archived** 'profile(s)' _from_ HrFlow _to_  |
| [**Create jobs in hrflow**](docs/create_jobs_in_hrflow.md) | Send **created** 'job(s)' _from_  _to_ HrFlow |
| [**Update jobs in hrflow**](docs/update_jobs_in_hrflow.md) | Send **updated** 'job(s)' _from_  _to_ HrFlow |
| [**Archive jobs in hrflow**](docs/archive_jobs_in_hrflow.md) | Send **archived** 'job(s)' _from_  _to_ HrFlow |


</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :


<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/44360e84-ec0c-49a1-81dd-799840613c6a width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄 Visit [Recruitee](https://recruitee.com/) to learn more.
- ⚙️ API documentation : [Recruitee API](https://api.recruitee.com/docs/index.html)
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/v2/connectors/recruitee) on our Github.



# 👏 Special Thanks
- 💻 HrFlow.ai :  [Nedhir Ebnou](https://github.com/itsnedhir) - Software Engineer
- 🤝 Tellent : **Nuno Sequeira &  Diana De Freitas - Integrations Partners** for their help and collaboration in building this integration
